@@ -168,7 +168,10 @@ def adjust_size():
 
 def get_emoji_size():
     with open('config.txt', 'r', encoding='utf-8') as f:
-        return len(set(f.read().split(' ')))
+        temp = set(f.read().split(' '))
+        if '' in temp:
+            temp.remove('')
+    return len(temp)
 
 
 def get_rand_emoji(length):
